# Brain Games
Brain Games is a Python library that provides oppotunity to play games with mathematical calculations.

____

### Hexlet tests and linter status:
[![Actions Status](https://github.com/Dddarknight/python-project-lvl1/workflows/hexlet-check/badge.svg)](https://github.com/Dddarknight/python-project-lvl1/actions)

![Linter](https://github.com/Dddarknight/python-project-lvl1/actions/workflows/linter.yml/badge.svg)

### CodeClimate:
<a href="https://codeclimate.com/github/Dddarknight/python-project-lvl1/maintainability"><img src="https://api.codeclimate.com/v1/badges/f0825e54a6e1af78ca05/maintainability" /></a>

## Links
This project was built using these tools:
| Tool | Description |
|----------|---------|
| [poetry](https://python-poetry.org/) |  "Python dependency management and packaging made easy" |

## Description
In each game you have to give 3 right answers to become a winner, otherwise the game ends. 
You can play any of the following games:
| Game name | Description |
|----------|---------|
| brain-calc | You need to make calculations with 2 given numbers|
| brain-even | You need to answer whether the given number is even or not|
| brain-gcd | You need to find the greatest common divisor of given numbers|
| brain-prime | You need to answer whether the given number is prime or not|
| brain-progression | You need to find the missing number in the progression|


## Usage
```
$ brain-calc
$ brain-even
$ brain-gcd
$ brain-prime
$ brain-progression
```

### Asciinema record:
[![asciinema](https://asciinema.org/a/uESMOk94NHGA705nEkQGoNAQh)](https://asciinema.org/a/uESMOk94NHGA705nEkQGoNAQh)

## License
[GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)
